<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="pl">
<context>
    <name>InfoPolylineArea</name>
    <message>
        <location filename="../InfoPolylineArea.js" line="+53"/>
        <source>Choose polyline</source>
        <translation>Proszę wskazać linię łamaną</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Done</source>
        <translation>Zrobione</translation>
    </message>
    <message>
        <location line="+45"/>
        <source>Area</source>
        <translation>Pole powierzchni</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Circumference</source>
        <translation>Obwód</translation>
    </message>
    <message>
        <location line="+60"/>
        <source>Polyline area:</source>
        <translation>Pole powierzchni linii łamanej:</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>circumference:</source>
        <translation>obwód:</translation>
    </message>
    <message>
        <location filename="../InfoPolylineAreaInit.js" line="+2"/>
        <source>Polyl&amp;ine Area</source>
        <translation>Pole powierzchni &amp;linii łamanej</translation>
    </message>
</context>
</TS>
